@@ -61,6 +61,7 @@ class ContainerEvent(Event, ABC):
 @dataclass(frozen=True, slots=True)
 class ContainerDependenciesUpdated(ContainerEvent):
     classes: Collection[type]
+    override: bool
 
     def __str__(self) -> str:
         length = len(self.classes)
@@ -132,15 +133,13 @@ Injectables
 class Injectable(Protocol[_T]):
     __slots__ = ()
 
-    def __init__(self, factory: Callable[[], _T] = ..., *args, **kwargs):
-        ...
+    def __init__(self, __factory: Callable[[], _T] = ..., /): ...
 
     @property
     def is_locked(self) -> bool:
         return False
 
-    def unlock(self):
-        ...
+    def unlock(self): ...
 
     @abstractmethod
     def get_instance(self) -> _T:
@@ -214,27 +213,20 @@ class Container:
     def __injectables(self) -> frozenset[Injectable]:
         return frozenset(self.__data.values())
 
-    def update(self, classes: Types, injectable: Injectable):
-        classes = frozenset(get_origins(*classes))
+    def update(self, classes: Types, injectable: Injectable, override: bool):
+        values = {origin: injectable for origin in get_origins(*classes)}
 
-        if classes:
-            event = ContainerDependenciesUpdated(self, classes)
+        if values:
+            event = ContainerDependenciesUpdated(self, values, override)
 
             with self.notify(event):
-                self.__data.update(
-                    (self.check_if_exists(cls), injectable) for cls in classes
-                )
+                if not override:
+                    self.__check_if_exists(*values)
+
+                self.__data.update(values)
 
         return self
 
-    def check_if_exists(self, cls: type) -> type:
-        if cls in self.__data:
-            raise RuntimeError(
-                f"An injectable already exists for the class `{format_type(cls)}`."
-            )
-
-        return cls
-
     def unlock(self):
         for injectable in self.__injectables:
             injectable.unlock()
@@ -246,6 +238,13 @@ class Container:
     def notify(self, event: Event) -> ContextManager | ContextDecorator:
         return self.__channel.dispatch(event)
 
+    def __check_if_exists(self, *classes: type):
+        for cls in classes:
+            if cls in self.__data:
+                raise RuntimeError(
+                    f"An injectable already exists for the class `{format_type(cls)}`."
+                )
+
 
 """
 Module
@@ -282,7 +281,7 @@ class Module(EventListener):
         raise NoInjectable(cls)
 
     def __setitem__(self, cls: type | UnionType, injectable: Injectable, /):
-        self.update((cls,), injectable)
+        self.update((cls,), injectable, override=True)
 
     def __contains__(self, cls: type | UnionType, /) -> bool:
         return any(cls in broker for broker in self.__brokers)
@@ -306,22 +305,29 @@ class Module(EventListener):
         *,
         cls: type[Injectable] = NewInjectable,
         on: type | Types = None,
+        override: bool = False,
     ):
         def decorator(wp):
             factory = self.inject(wp, return_factory=True)
             injectable = cls(factory)
             classes = find_types(wp, on)
-            self.update(classes, injectable)
+            self.update(classes, injectable, override)
             return wp
 
         return decorator(wrapped) if wrapped else decorator
 
     singleton = partialmethod(injectable, cls=SingletonInjectable)
 
-    def set_constant(self, instance: _T, on: type | Types = None) -> _T:
+    def set_constant(
+        self,
+        instance: _T,
+        on: type | Types = None,
+        *,
+        override: bool = False,
+    ) -> _T:
         cls = type(instance)
 
-        @self.injectable(on=(cls, on))
+        @self.injectable(on=(cls, on), override=override)
         def get_constant():
             return instance
 
@@ -332,29 +338,33 @@ class Module(EventListener):
         wrapped: Callable[..., Any] = None,
         /,
         *,
+        force: bool = False,
         return_factory: bool = False,
     ):
         def decorator(wp):
             if not return_factory and isclass(wp):
-                wp.__init__ = decorator(wp.__init__)
+                wp.__init__ = self.inject(wp.__init__, force=force)
                 return wp
 
             lazy_binder = Lazy[Binder](lambda: self.__new_binder(wp))
 
             @wraps(wp)
             def wrapper(*args, **kwargs):
-                arguments = (~lazy_binder).bind(*args, **kwargs)
+                arguments = (~lazy_binder).bind(args, kwargs, force)
                 return wp(*arguments.args, **arguments.kwargs)
 
             return wrapper
 
         return decorator(wrapped) if wrapped else decorator
 
-    def get_instance(self, cls: type[_T]) -> _T | None:
+    def get_instance(self, cls: type[_T], none: bool = True) -> _T | None:
         try:
             injectable = self[cls]
-        except KeyError:
-            return None
+        except KeyError as exc:
+            if none:
+                return None
+
+            raise exc from exc
 
         instance = injectable.get_instance()
         return cast(cls, instance)
@@ -362,8 +372,8 @@ class Module(EventListener):
     def get_lazy_instance(self, cls: type[_T]) -> Lazy[_T | None]:
         return Lazy(lambda: self.get_instance(cls))
 
-    def update(self, classes: Types, injectable: Injectable):
-        self.__container.update(classes, injectable)
+    def update(self, classes: Types, injectable: Injectable, override: bool = False):
+        self.__container.update(classes, injectable, override)
         return self
 
     def use(
@@ -476,8 +486,8 @@ class Dependencies:
             yield name, injectable.get_instance()
 
     @property
-    def arguments(self) -> dict[str, Any]:
-        return dict(self)
+    def arguments(self) -> OrderedDict[str, Any]:
+        return OrderedDict(self)
 
     @classmethod
     def from_mapping(cls, mapping: Mapping[str, Injectable]):
@@ -519,12 +529,26 @@ class Binder(EventListener):
         self.__signature = signature
         self.__dependencies = Dependencies.empty()
 
-    def bind(self, /, *args, **kwargs) -> Arguments:
+    def bind(
+        self,
+        args: Iterable[Any] = (),
+        kwargs: Mapping[str, Any] = None,
+        force: bool = False,
+    ) -> Arguments:
+        if kwargs is None:
+            kwargs = {}
+
         if not self.__dependencies:
             return Arguments(args, kwargs)
 
         bound = self.__signature.bind_partial(*args, **kwargs)
-        bound.arguments = self.__dependencies.arguments | bound.arguments
+        dependencies = self.__dependencies.arguments
+
+        if force:
+            bound.arguments |= dependencies
+        else:
+            bound.arguments = dependencies | bound.arguments
+
         return Arguments(bound.args, bound.kwargs)
 
     def update(self, module: Module):
@@ -532,8 +556,7 @@ class Binder(EventListener):
         return self
 
     @singledispatchmethod
-    def on_event(self, event: Event, /):
-        ...
+    def on_event(self, event: Event, /): ...
 
     @on_event.register
     @contextmanager
